==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebFilteringEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringEventArgsDetailDescriptionMetadata } from "./WebFilteringEventArgsDetailDescriptionMetadata";
import { WebFilteringEventArgsDescription } from "./WebFilteringEventArgsDescription";
/**
 * @hidden
 */
var WebFilteringEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFilteringEventArgsDescriptionMetadata, _super);
    function WebFilteringEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFilteringEventArgsDescriptionMetadata.b = function (a) {
        if (WebFilteringEventArgsDescriptionMetadata.a == null) {
            WebFilteringEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFilteringEventArgsDescriptionMetadata.c(WebFilteringEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebFilteringEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebFilteringEventArgsDescriptionMetadata.a);
        WebFilteringEventArgsDetailDescriptionMetadata.d(a);
    };
    WebFilteringEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FilteringEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("Detail", "ExportedType:WebFilteringEventArgsDetail");
    };
    WebFilteringEventArgsDescriptionMetadata.d = function (a) {
        WebFilteringEventArgsDescriptionMetadata.b(a);
        a.aa("WebFilteringEventArgs", function () { return new WebFilteringEventArgsDescription(); });
        a.z("WebFilteringEventArgs", WebFilteringEventArgsDescriptionMetadata.a);
    };
    WebFilteringEventArgsDescriptionMetadata.$t = markType(WebFilteringEventArgsDescriptionMetadata, 'WebFilteringEventArgsDescriptionMetadata');
    WebFilteringEventArgsDescriptionMetadata.a = null;
    return WebFilteringEventArgsDescriptionMetadata;
}(Base));
export { WebFilteringEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebFilteringEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringEventArgsDetailDescriptionMetadata } from "./WebFilteringEventArgsDetailDescriptionMetadata";
import { WebFilteringEventArgsDescription } from "./WebFilteringEventArgsDescription";
/**
 * @hidden
 */
var WebFilteringEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFilteringEventArgsDescriptionMetadata, _super);
    function WebFilteringEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFilteringEventArgsDescriptionMetadata.b = function (a) {
        if (WebFilteringEventArgsDescriptionMetadata.a == null) {
            WebFilteringEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFilteringEventArgsDescriptionMetadata.c(WebFilteringEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebFilteringEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebFilteringEventArgsDescriptionMetadata.a);
        WebFilteringEventArgsDetailDescriptionMetadata.d(a);
    };
    WebFilteringEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FilteringEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebFilteringEventArgsDetail");
    };
    WebFilteringEventArgsDescriptionMetadata.d = function (a) {
        WebFilteringEventArgsDescriptionMetadata.b(a);
        a.ac("WebFilteringEventArgs", function () { return new WebFilteringEventArgsDescription(); });
        a.ab("WebFilteringEventArgs", WebFilteringEventArgsDescriptionMetadata.a);
    };
    WebFilteringEventArgsDescriptionMetadata.$t = markType(WebFilteringEventArgsDescriptionMetadata, 'WebFilteringEventArgsDescriptionMetadata');
    WebFilteringEventArgsDescriptionMetadata.a = null;
    return WebFilteringEventArgsDescriptionMetadata;
}(Base));
export { WebFilteringEventArgsDescriptionMetadata };
